==> mysql-8.0.35.tar.gz: mysql-8.0.35/storage/myisammrg/myrg_update.cc <==
/* Copyright (c) 2000, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

/* Update last read record */

#include "my_inttypes.h"
#include "my_thread_local.h"
#include "storage/myisammrg/myrg_def.h"

int myrg_update(MYRG_INFO *info, const uchar *oldrec, uchar *newrec) {
  if (!info->current_table) {
    set_my_errno(HA_ERR_NO_ACTIVE_RECORD);
    return HA_ERR_NO_ACTIVE_RECORD;
  }

  return mi_update(info->current_table->table, oldrec, newrec);
}

==> mysql-8.4.0.tar.gz: mysql-8.4.0/storage/myisammrg/myrg_update.cc <==
/* Copyright (c) 2000, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

/* Update last read record */

#include "my_inttypes.h"
#include "my_thread_local.h"
#include "storage/myisammrg/myrg_def.h"

int myrg_update(MYRG_INFO *info, const uchar *oldrec, uchar *newrec) {
  if (!info->current_table) {
    set_my_errno(HA_ERR_NO_ACTIVE_RECORD);
    return HA_ERR_NO_ACTIVE_RECORD;
  }

  return mi_update(info->current_table->table, oldrec, newrec);
}
